<script setup lang="tsx">
import { cusExtendInfo } from "@/api/mine";
import { message } from "@/utils/message";
import { onMounted, reactive } from "vue";
import {
  addDialog,
  closeDialog,
  updateDialog,
  closeAllDialog
} from "@/components/ReDialog";
let state = reactive({
  userInfo: {}
});
onMounted(async () => {
  let res = await cusExtendInfo();
  if (res.code == 200) {
    state.userInfo = res.result;
  } else {
    message(res.message, {
      type: "error"
    });
  }
});
const showImg = name => {
  addDialog({
    width: "40%",
    title: "查看营业执照",
    contentRenderer: () => <img src={state.userInfo[name]} />, // jsx 语法 （注意在.vue文件启用jsx语法，需要在script开启lang="tsx"）
    closeCallBack: ({ options, args }) => {
      // options.props 是响应式的
      // const { formInline } = options.props as FormProps;
      // const text = `姓名：${formInline.user} 城市：${formInline.region}`;
      if (args?.command === "cancel") {
        // 您点击了取消按钮
        // active.value -= 1;
      } else if (args?.command === "sure") {
      } else {
      }
    }
  });
};
defineOptions({
  name: "mine"
});
</script>

<template>
  <el-descriptions class="margin-top" title="" :column="3" :size="size" border>
    <!-- <template #extra>
      <el-button type="primary">Operation</el-button>
    </template> -->
    <el-descriptions-item :span="3">
      <template #label>
        <div class="cell-item">交易主体</div>
      </template>
      {{ state.userInfo.transactionCode }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">企业名称</div>
      </template>
      {{ state.userInfo.enterpriseName }}

      <span @click="showImg('businessLicense')">
        <el-link type="primary" underline>查看营业执照</el-link>
      </span>
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">统一社会信用代码</div>
      </template>
      {{ state.userInfo.unifiedSocialCreditCode }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">注册资金</div>
      </template>
      {{ state.userInfo.registeredCapital }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">企业类型</div>
      </template>
      {{ state.userInfo.enterpriseType }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">住所地</div>
      </template>
      {{ state.userInfo.residence }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">联系电话</div>
      </template>
      {{ state.userInfo.legalRepresentativePhone }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">成立时间</div>
      </template>
      {{ state.userInfo.establishmentTime }}
    </el-descriptions-item>
    <el-descriptions-item :span="2">
      <template #label>
        <div class="cell-item">电子邮箱</div>
      </template>
      {{ state.userInfo.enterpriseEmail }}
    </el-descriptions-item>
    <el-descriptions-item :span="3" label-width="100">
      <template #label>
        <div class="cell-item">主营业务</div>
      </template>
      {{ state.userInfo.mainBusiness }}
    </el-descriptions-item>

    <el-descriptions-item>
      <template #label>
        <div class="cell-item">法定代表人</div>
      </template>
      {{ state.userInfo.legalRepresentativeName }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">身份证</div>
      </template>
      {{ state.userInfo.legalRepresentativeIdNumber }}
      <span @click="showImg('legalRepresentativeIdCard')">
        <el-link type="primary" underline>查看身份证</el-link>
      </span>
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">联系电话</div>
      </template>
      {{ state.userInfo.legalRepresentativePhone }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">业务经办人</div>
      </template>
      {{ state.userInfo.operatorName }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">身份证</div>
      </template>
      {{ state.userInfo.operatorIdNumber }}
      <span style="margin-right: auto" @click="showImg('operatorIdCard')">
        <el-link type="primary" underline>查看身份证</el-link>
      </span>
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">联系电话</div>
      </template>
      {{ state.userInfo.operatorPhone }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">开户银行</div>
      </template>
      {{ state.userInfo.bankName }}
    </el-descriptions-item>
    <el-descriptions-item>
      <template #label>
        <div class="cell-item">银行账号</div>
      </template>
      {{ state.userInfo.bankAccount }}
    </el-descriptions-item>
  </el-descriptions>
</template>

<style lang="scss">
.el-descriptions {
  margin-top: 20px;
}
.cell-item {
  display: flex;
  align-items: center;
}
.flex-between {
  height: 100%;
  display: flex;
  justify-content: space-between;
}
.element {
  position: absolute;
  right: 0;
}
</style>
